/**
 * (c) Copyright 2022 xsbee.
 *
 * This file is part of audcast.
 *
 * audcast is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * audcast is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this
 * program. If not, see <https://www.gnu.org/licenses/>.
 */

#include <twolame.h>

#include <netinet/in.h>
#include <arpa/inet.h>

#ifndef _AUDCAST_UTIL
#define _AUDCAST_UTIL

static void
dump_mp2_config (twolame_options* opts, FILE* out)
{
	const char *version, *mode, *vbr;
	int framelength, in_samplerate, out_samplerate, bitrate;
	float vbr_level;

	version = twolame_get_version_name (opts);
	mode = twolame_get_mode_name (opts);
	vbr = twolame_get_VBR (opts) ? "yes" : "no";
	framelength = twolame_get_framelength (opts);
	in_samplerate = twolame_get_in_samplerate (opts);
	out_samplerate = twolame_get_out_samplerate (opts);
	bitrate = twolame_get_bitrate (opts);
	vbr_level = twolame_get_VBR_level (opts);

	fprintf (out, "info: MPEG Version  %s\n"
				  "      MPEG Mode     %s\n"
				  "      Framelength   %d\n"
				  "      VBR?          %s (%f)\n"
				  "      Samplerate    %d (in) %d (out)\n"
				  "      Bitrate       %dk/s\n",

				  version, mode, framelength, vbr, vbr_level,
				  in_samplerate, out_samplerate, bitrate);
}

static char*
repr_of_sockaddr (struct sockaddr * addr)
{
	char * repr;
	char addr_repr [INET_ADDRSTRLEN];

	struct sockaddr_in * addr_in = (struct sockaddr_in *) addr;  /* IPv4 */
	struct sockaddr_in6 * addr_in6 = (struct sockaddr_in6 *) addr;  /* IPv6 */

	switch (addr->sa_family)
	{
	/* IPv4 */
	case AF_INET:
		inet_ntop (AF_INET, &addr_in->sin_addr, addr_repr, INET6_ADDRSTRLEN);
		asprintf (&repr, "%s:%d", addr_repr, ntohs(addr_in->sin_port));
		break;

	/* IPv6 */
	case AF_INET6:
		inet_ntop (AF_INET6, &addr_in6->sin6_addr, addr_repr, INET6_ADDRSTRLEN);
		asprintf (&repr, "[%s]:%d", addr_repr, ntohs(addr_in6->sin6_port));
		break;

	default:
		return NULL;
	}

	return repr;
}

/* https://stackoverflow.com/a/9194117 */
static int
round_up_int (int x, int m)
{
    return (x + m - 1) & -m;
}

#endif

